## Summary

<!-- Brief description of the changes in this PR -->

## Type of Change

- [ ] 🐛 Bug fix (non-breaking change that fixes an issue)
- [ ] ✨ Feature (non-breaking change that adds functionality)
- [ ] 📝 Documentation (updates to docs, README, or comments)
- [ ] 🧪 Test (adding or updating tests)
- [ ] 🔧 Chore (refactoring, CI, dependencies, etc.)
- [ ] 💥 Breaking change (fix or feature that would break existing functionality)

## Testing Done

<!-- Describe the tests you ran and how to reproduce them -->

## Checklist

- [ ] All tests pass (`pytest`)
- [ ] Documentation updated (if applicable)
- [ ] Commit messages follow [Conventional Commits](https://www.conventionalcommits.org/)
- [ ] No new warnings or linting errors
